import { LitElement, PropertyValueMap } from 'lit';
export declare type InputType = 'text' | 'tel' | 'url' | 'email' | 'password' | 'date' | 'month' | 'week' | 'time' | 'datetime-local' | 'number' | 'color';
declare const UUIInputElement_base: (new (...args: any[]) => import("@umbraco-ui/uui-base/lib/mixins").FormControlMixinInterface) & typeof LitElement;
/**
 * Custom element wrapping the native input element.This is a formAssociated element, meaning it can participate in a native HTMLForm. A name:value pair will be submitted.
 * @element uui-input
 * @slot input label - for the input label text.
 * @slot prepend - for components to render to the left of the input.
 * @slot append - for components to render to the right of the input.
 * @fires UUIInputEvent#change on change
 * @fires InputEvent#input on input
 * @fires KeyboardEvent#keyup on keyup
 */
export declare class UUIInputElement extends UUIInputElement_base {
    /**
     * This is a static class field indicating that the element is can be used inside a native form and participate in its events. It may require a polyfill, check support here https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/attachInternals.  Read more about form controls here https://web.dev/more-capable-form-controls/
     * @type {boolean}
     */
    static readonly formAssociated = true;
    static styles: import("lit").CSSResult[];
    /**
     * This is a minimum value of the input.
     * @type {number}
     * @attr
     * @default undefined
     */
    minlength?: number;
    /**
     * Minlength validation message.
     * @type {boolean}
     * @attr
     * @default
     */
    minlengthMessage: string;
    /**
     * This is a maximum value of the input.
     * @type {number}
     * @attr
     * @default undefined
     */
    maxlength?: number;
    /**
     * Maxlength validation message.
     * @type {boolean}
     * @attr
     * @default
     */
    maxlengthMessage: string;
    /**
     * Disables the input.
     * @type {boolean}
     * @attr
     * @default false
     */
    disabled: boolean;
    /**
     * Sets the input to readonly mode, meaning value cannot be changed but still able to read and select its content.
     * @type {boolean}
     * @attr
     * @default false
     */
    readonly: boolean;
    /**
     * Label for input element.
     * @type {string}
     * @attr
     */
    label: string;
    /**
     * Defines the input placeholder.
     * @type {string}
     * @attr
     * @default ''
     */
    placeholder: string;
    /**
     * This property specifies the type of input that will be rendered.
     * @type {'text' | 'tel'| 'url'| 'email'| 'password'| 'date'| 'month'| 'week'| 'time'| 'datetime-local'| 'number'| 'color'}
     * @attr
     * @default text
     */
    get type(): InputType;
    set type(value: InputType);
    _input: HTMLInputElement;
    private _type;
    constructor();
    protected firstUpdated(_changedProperties: PropertyValueMap<any> | Map<PropertyKey, unknown>): void;
    /**
     * This method enables <label for="..."> to focus the input
     */
    focus(): void;
    protected getFormElement(): HTMLElement;
    protected onInput(e: Event): void;
    protected onChange(): void;
    protected renderPrepend(): import("lit-html").TemplateResult<1>;
    protected renderAppend(): import("lit-html").TemplateResult<1>;
    render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'uui-input': UUIInputElement;
    }
}
export {};
